@@ -30,6 +30,7 @@ class Component:
         self.type = ''
         self.version = ''
         self.depends = [] # [{'aos':'v7.3'},{'kv':'v7.4'}]
+        self.depends_forward = [] # [{'aos':'v7.3'},{'kv':">= v7.4"}]
         self.description = ''
         self.historyVersion = {}
         self.updated = ''
@@ -127,19 +128,7 @@ class Component:
                 return
 
             git = GitRepo(self.path, self.repo_url)
-            # 如果找不到对应的branch，则clone master分支
-            branches = git.GetRemoteBranches('origin')
-            tags = git.GetRemoteTags('origin')
-            if len(branches) == 0:
-                if len(tags) == 0:
-                    put_string('There is no branch/tag found for component:%s in remote.' % self.name, level='warning')
-                    return
-                branches = tags
-            if branch not in branches and branch not in tags:
-                put_string("%-16s(%s->master), clone %s ..." % (self.name, branch, self.repo_url), level='warning')
-                branch = 'master'
-            else:
-                put_string("%-16s(%s), clone %s ..." % (self.name, branch, self.repo_url))
+            put_string("%-16s(%s), clone %s ..." % (self.name, branch, self.repo_url))
             git.pull(branch, None)
 
         elif self.version in self.historyVersion.keys():
@@ -258,6 +247,13 @@ class Component:
         for d in pack.depends:
             if type(d) == dict:
                 self.depends.append(d)
+        self.depends_forward = []
+        for d in pack.depends_forward:
+            if type(d) == dict:
+                self.depends_forward.append(d)
+        if len(self.depends_forward) > 0:
+            self.depends = self.depends_forward
+
         # append sdk_chip
         for d in pack.sdk_chip:
             if type(d) == dict:
