@@ -27,8 +27,8 @@ Search for components whose name or summary contains <query>
         if len(args) != 1:
             self.Usage()
         kword = args[0]
-        if is_contain_chinese(kword.encode('utf8').decode('utf8')):
-            put_string("Not support search chinese string!")
+        if is_contain_chinese(kword):
+            put_string("Not support search chinese string!", level='error')
             exit(-1)
 
         yoc = YoC()
