@@ -1,6 +1,6 @@
 # -*- coding:utf-8 -*-
 #
-# Copyright (C) 2015-2020 Alibaba Group Holding Limited
+# Copyright (C) 2019-2020 Alibaba Group Holding Limited
 
 
 from __future__ import print_function
@@ -28,4 +28,4 @@ Uninstall component.
             for name in args:
                 if yoc.remove_component(name):
                     yoc.update()
-                    print("%s uninstall Success!" % name)
+                    put_string("%s uninstall Success!" % name)
