@@ -38,7 +38,7 @@ add or delete user to repo
         if opt.reponame:
             reponame = opt.reponame
         else:
-            yoc.gitee_update()
+            yoc.update(True)
 
         repo = RepoGitee(yoc.conf.gitee_token, yoc.conf.group)
         if opt.add:
